@@ -1,4 +1,4 @@
-#-*-coding:utf-8-*-
+# -*- coding: utf-8 -*-
 # test_git.py
 # Copyright (C) 2008, 2009 Michael Trier (mtrier@gmail.com) and contributors
 #
@@ -7,18 +7,19 @@
 import os
 
 from git.test.lib import TestBase
-from gitdb.test.lib import with_rw_directory
+from gitdb.test.lib import skip_on_travis_ci, with_rw_directory
 
 
 class Tutorials(TestBase):
 
+    @skip_on_travis_ci
     @with_rw_directory
     def test_init_repo_object(self, rw_dir):
         # [1-test_init_repo_object]
         from git import Repo
         join = os.path.join
 
-        # rorepo is a a Repo instance pointing to the git-python repository.
+        # rorepo is a Repo instance pointing to the git-python repository.
         # For all you know, the first argument to Repo is a path to the repository
         # you want to work with
         repo = Repo(self.rorepo.working_tree_dir)
@@ -94,7 +95,7 @@ class Tutorials(TestBase):
         # [11-test_init_repo_object]
         assert now.commit.message != past.commit.message
         # You can read objects directly through binary streams, no working tree required
-        assert (now.commit.tree / 'VERSION').data_stream.read().decode('ascii').startswith('1')
+        assert (now.commit.tree / 'VERSION').data_stream.read().decode('ascii').startswith('2')
 
         # You can traverse trees as well to handle all contained files of a particular commit
         file_count = 0
@@ -165,7 +166,7 @@ class Tutorials(TestBase):
         for sm in cloned_repo.submodules:
             assert not sm.remove().exists()                   # after removal, the sm doesn't exist anymore
         sm = cloned_repo.create_submodule('mysubrepo', 'path/to/subrepo', url=bare_repo.git_dir, branch='master')
-        
+
         # .gitmodules was written and added to the index, which is now being committed
         cloned_repo.index.commit("Added submodule")
         assert sm.exists() and sm.module_exists()             # this submodule is defintely available
@@ -395,7 +396,7 @@ class Tutorials(TestBase):
         hcommit.diff()                  # diff tree against index
         hcommit.diff('HEAD~1')          # diff tree against previous tree
         hcommit.diff(None)              # diff tree against working tree
-        
+
         index = repo.index
         index.diff()                    # diff index against itself yielding empty diff
         index.diff(None)                # diff index against working copy
@@ -446,7 +447,7 @@ class Tutorials(TestBase):
         sm = sms[0]
         assert sm.name == 'gitdb'                         # git-python has gitdb as single submodule ...
         assert sm.children()[0].name == 'smmap'           # ... which has smmap as single submodule
-        
+
         # The module is the repository referenced by the submodule
         assert sm.module_exists()                         # the module is available, which doesn't have to be the case.
         assert sm.module().working_tree_dir.endswith('gitdb')
@@ -458,7 +459,7 @@ class Tutorials(TestBase):
         assert sm.config_reader().get_value('path') == sm.path
         assert len(sm.children()) == 1                    # query the submodule hierarchy
         # ![1-test_submodules]
-        
+
     @with_rw_directory
     def test_add_file_and_commit(self, rw_dir):
         import git
